@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.Part;
+import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeBodyPart;
@@ -283,6 +284,9 @@ public class GmailSendTransport extends MailTransport {
 
                 throw MailExceptionCode.MAIL_TRANSPORT_DISABLED.create(gmailSendConfig.getServer(), gmailSendConfig.getLogin(), I(session.getUserId()), I(session.getContextId()));
             }
+            if (account.isDeactivated()) {
+                throw MailExceptionCode.MAIL_TRANSPORT_DEACTIVATED.create(gmailSendConfig.getServer(), gmailSendConfig.getLogin(), I(session.getUserId()), I(session.getContextId()));
+            }
             if (TransportAuth.considerAsMailTransportAuth(account.getTransportAuth()) && (account instanceof MailAccount)) {
                 MailAccount mailAccount = (MailAccount) account;
                 if (mailAccount.isMailDisabled()) {
@@ -560,19 +564,31 @@ public class GmailSendTransport extends MailTransport {
             }
 
             MimeMessage mimeMessage = new MimeMessage(getJavaMailSession());
-            String userMail = user.getMail();
 
             // Set from
-            String from;
+            InternetAddress from;
             if (fromAddr == null) {
-                if ((usm.getSendAddr() == null) && (userMail == null)) {
-                    throw GmailSendExceptionCode.NO_SEND_ADDRESS_FOUND.create();
+                String sendAddress = usm.getSendAddr();
+                if (sendAddress == null) {
+                    sendAddress = UserStorage.getInstance().getUser(session.getUserId(), ctx).getMail();
+                    if (sendAddress == null) {
+                        throw GmailSendExceptionCode.NO_SEND_ADDRESS_FOUND.create();
+                    }
                 }
-                from = usm.getSendAddr() == null ? userMail : usm.getSendAddr();
+                InternetAddress[] addressList = parseAddressList(sendAddress, false);
+                from = addressList[0];
+                mimeMessage.addFrom(addressList);
             } else {
-                from = fromAddr;
+                try {
+                    InternetAddress[] addrs = QuotedInternetAddress.parse(fromAddr, false);
+                    mimeMessage.addFrom(addrs);
+                    from = addrs[0];
+                } catch (AddressException e) {
+                    InternetAddress addr = MimeMessageUtility.parseCraftedAddress(fromAddr);
+                    mimeMessage.addFrom(new Address[] { addr });
+                    from = addr;
+                }
             }
-            mimeMessage.addFrom(parseAddressList(from, false));
 
             // Set to
             final Address[] recipients = new Address[] { dispNotification };
@@ -604,7 +620,8 @@ public class GmailSendTransport extends MailTransport {
             }
 
             // Set common headers
-            new GmailSendMessageFiller(session, ctx, usm).setAccountId(accountId).setCommonHeaders(mimeMessage);
+            int remotePort = Strings.parsePositiveInt(LogProperties.get(LogProperties.Name.GRIZZLY_REMOTE_PORT));
+            new GmailSendMessageFiller(session, remotePort, ctx, usm).setAccountId(accountId).setCommonHeaders(mimeMessage);
 
             // Compose body
             String defaultMimeCS = MailProperties.getInstance().getDefaultMimeCharset();
@@ -615,7 +632,7 @@ public class GmailSendTransport extends MailTransport {
             final Date sentDate = srcMail.getSentDate();
             {
                 final MimeBodyPart text = new MimeBodyPart();
-                final String txt = performLineFolding(strHelper.getString(MailStrings.ACK_NOTIFICATION_TEXT).replaceFirst("#DATE#", sentDate == null ? "" : quoteReplacement(DateFormat.getDateInstance(DateFormat.LONG, locale).format(sentDate))).replaceFirst("#RECIPIENT#", quoteReplacement(from)).replaceFirst("#SUBJECT#", quoteReplacement(srcMail.getSubject())), usm.getAutoLinebreak());
+                final String txt = performLineFolding(strHelper.getString(MailStrings.ACK_NOTIFICATION_TEXT).replaceFirst("#DATE#", sentDate == null ? "" : quoteReplacement(DateFormat.getDateInstance(DateFormat.LONG, locale).format(sentDate))).replaceFirst("#RECIPIENT#", quoteReplacement(craftDisplayStringFrom(from))).replaceFirst("#SUBJECT#", quoteReplacement(srcMail.getSubject())), usm.getAutoLinebreak());
                 MessageUtility.setText(txt, defaultMimeCS, text);
                 // text.setText(txt,defaultMimeCS);
                 text.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
@@ -628,7 +645,7 @@ public class GmailSendTransport extends MailTransport {
             {
                 final MimeBodyPart ack = new MimeBodyPart();
                 final String msgId = srcMail.getFirstHeader(MessageHeaders.HDR_MESSAGE_ID);
-                final String txt = strHelper.getString(ACK_TEXT).replaceFirst("#FROM#", quoteReplacement(from)).replaceFirst("#MSG ID#", quoteReplacement(msgId));
+                final String txt = strHelper.getString(ACK_TEXT).replaceFirst("#FROM#", quoteReplacement(from.toUnicodeString())).replaceFirst("#MSG ID#", quoteReplacement(msgId));
                 MessageUtility.setText(txt, defaultMimeCS, ack);
                 // ack.setText(txt,defaultMimeCS);
                 ack.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
@@ -645,6 +662,14 @@ public class GmailSendTransport extends MailTransport {
         }
     }
 
+    private static String craftDisplayStringFrom(InternetAddress address) {
+        String personal = address.getPersonal();
+        if (Strings.isEmpty(personal)) {
+            return address.getAddress();
+        }
+        return new StringBuilder(personal).append(" <").append(address.getAddress()).append('>').toString();
+    }
+
     @Override
     public MailMessage sendMailMessage(ComposedMailMessage transportMail, ComposeType sendType, Address[] allRecipients) throws OXException {
         GmailSendConfig gmailSendConfig = getTransportConfig();
@@ -1104,7 +1129,7 @@ public class GmailSendTransport extends MailTransport {
         try {
             access = MailAccess.getInstance(session, msgref.getAccountId());
             access.connect();
-            MimeMessageFiller.setReplyHeaders(access.getMessageStorage().getMessage(msgref.getFolder(), msgref.getMailID(), false), mimeMessage);
+            MimeMessageFiller.setReplyHeaders(access.getMessageStorage().getMessage(msgref.getFolder(), msgref.getMailID(), false), mimeMessage, I(MailProperties.getInstance().getMaxLengthForReferencesHeader(session.getUserId(), session.getContextId())));
         } finally {
             if (null != access) {
                 access.close(true);
@@ -1113,7 +1138,8 @@ public class GmailSendTransport extends MailTransport {
     }
 
     private GmailSendMessageFiller createGmailSendMessageFiller(UserSettingMail optMailSettings) {
-        return new GmailSendMessageFiller(session, ctx, null == optMailSettings ? usm : optMailSettings);
+        String remotePort = LogProperties.get(LogProperties.Name.GRIZZLY_REMOTE_PORT);
+        return new GmailSendMessageFiller(session, Strings.parsePositiveInt(remotePort), ctx, null == optMailSettings ? usm : optMailSettings);
     }
 
     @Override
