@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,9 @@
 package com.openexchange.gmail.send.config;
 
 import java.util.Properties;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Interests;
+import com.openexchange.config.Reloadable;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
@@ -43,6 +46,21 @@ public final class GmailSendSessionProperties {
         super();
     }
 
+    static {
+        GmailSendReloadable.getInstance().addReloadable(new Reloadable() {
+
+            @Override
+            public void reloadConfiguration(ConfigurationService configService) {
+                sessionProperties = null;
+            }
+
+            @Override
+            public Interests getInterests() {
+                return null;
+            }
+        });
+    }
+
     /**
      * Creates a <b>cloned</b> version of default Gmail Send session properties
      *
