@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,6 +26,8 @@ import java.io.InputStream;
 import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -70,6 +72,11 @@ public class MicrosoftGraphDriveServiceImpl implements MicrosoftGraphDriveServic
      */
     private static final String ROOT_ID = "";
 
+    /**
+     * {@link Pattern} to match the skiptoken part of an url
+     */
+    private static final Pattern SKIPTOKEN_REGEX = Pattern.compile("skiptoken=([^\\n\\r&]+)");
+
     private final MicrosoftGraphOneDriveAPI api;
     private final OneDriveFolderParser folderEntityParser;
     private final OneDriveFileParser fileEntityParser;
@@ -469,21 +476,19 @@ public class MicrosoftGraphDriveServiceImpl implements MicrosoftGraphDriveServic
      * @param response The {@link JSONObject} response body
      * @return the skipToken or <code>null</code> if none available.
      */
-    private String extractSkipToken(JSONObject response) {
+    private static String extractSkipToken(JSONObject response) {
         String nextLink = response.optString("@odata.nextLink");
         if (Strings.isEmpty(nextLink)) {
             return null;
         }
-        int indexOfKey = nextLink.indexOf("skiptoken");
-        if (indexOfKey < 0) {
+
+        Matcher matcher = SKIPTOKEN_REGEX.matcher(nextLink);
+        if (matcher.find() == false) {
             return null;
         }
-        int indexOfValue = nextLink.indexOf('=', indexOfKey);
-        if (indexOfValue < 0) {
-            return null;
-        }
-        int indexOfLast = nextLink.indexOf('=', indexOfValue);
-        return ((indexOfLast < 0)) ? nextLink.substring(indexOfValue) : nextLink.substring(indexOfValue, indexOfLast);
+
+        String result = matcher.group(1);
+        return Strings.isEmpty(result) ? null : result;
     }
 
     /**
