@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ import com.openexchange.context.ContextService;
 import com.openexchange.context.PoolAndSchema;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.contexts.UpdateBehavior;
 
 /**
  * {@link OSGiContextService}
@@ -73,8 +74,8 @@ public final class OSGiContextService extends AbstractOSGiDelegateService<Contex
     }
 
     @Override
-    public Context getContext(int contextId) throws OXException {
-        return getService().getContext(contextId);
+    public Context getContext(int contextId, UpdateBehavior updateBehavior) throws OXException {
+        return getService().getContext(contextId, updateBehavior);
     }
 
     @Override
@@ -102,8 +103,8 @@ public final class OSGiContextService extends AbstractOSGiDelegateService<Contex
     }
 
     @Override
-    public Context loadContext(final int contextId) throws OXException {
-        return getService().loadContext(contextId);
+    public Context loadContext(int contextId, UpdateBehavior updateBehavior) throws OXException {
+        return getService().loadContext(contextId, updateBehavior);
     }
 
 }
