@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,7 +25,7 @@ import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.OAuthService;
-import com.openexchange.oauth.http.OAuthHTTPClientFactory;
+import com.openexchange.oauth.http.OAuthProxyHttpHelper;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
 /**
@@ -35,8 +35,8 @@ public class OAuthProxyActionFactory implements AJAXActionServiceFactory {
 
     private final AJAXActionService proxyAction;
 
-    public OAuthProxyActionFactory(OAuthService service, OAuthHTTPClientFactory clients) {
-        proxyAction = new OAuthProxyAction(service, clients);
+    public OAuthProxyActionFactory(OAuthService service, OAuthProxyHttpHelper helper) {
+        proxyAction = new OAuthProxyAction(service, helper);
     }
 
     @Override
