@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ import com.openexchange.oauth.OAuthAPIRegistry;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.OAuthService;
+import com.openexchange.oauth.http.HTTPMethod;
 import com.openexchange.oauth.json.Services;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -250,10 +251,6 @@ public class OAuthProxyRequest {
         }))
         .build();
 
-    public static enum HTTPMethod {
-        GET, PUT, POST, DELETE
-    }
-
     // -------------------------------------------------------------------------------------------------------------------------------------
 
 	private final AJAXRequestData req;
