@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -470,7 +470,7 @@ public class RESTUtility {
             Map<String, String> result = new HashMap<String, String>();
             while (scanner.hasNext()) {
                 final String nameValue = scanner.next();
-                final String[] parts = nameValue.split("=");
+                final String[] parts = Strings.splitBy(nameValue, '=', true);
                 if (parts.length != 2) {
                     throw new XingParseException("Bad query string from Xing.");
                 }
